# WebView2

These DLLs are the official stable release v1.0.2592.51 (net462), downloaded from
[NuGet](https://www.nuget.org/packages/Microsoft.Web.WebView2). They are
released under the terms of the [license in this folder](./LICENSE.md).

For details on usage and distribution, see [the Microsoft WebView2
documentation](https://docs.microsoft.com/en-us/microsoft-edge/webview2/)

Before use, the end-user must have the WebView2 Runtime installed. Details can
be found [here](https://developer.microsoft.com/en-us/microsoft-edge/webview2/#download-section).
